@@ -90,8 +90,9 @@ public:
     Q_INVOKABLE Article* get(int row) const;
     
     QModelIndexList match(const QModelIndex &start, int role, const QVariant &value, int hits = 1,
-                          Qt::MatchFlags flags = Qt::MatchFlags(Qt::MatchStartsWith | Qt::MatchWrap)) const;
-    Q_INVOKABLE int match(const QByteArray &role, const QVariant &value) const;
+                          Qt::MatchFlags flags = Qt::MatchFlags(Qt::MatchExactly | Qt::MatchWrap)) const;
+    Q_INVOKABLE int match(int start, const QByteArray &role, const QVariant &value,
+                          int flags = Qt::MatchFlags(Qt::MatchExactly | Qt::MatchWrap)) const;
 
 public Q_SLOTS:
     void clear();
