@@ -20,26 +20,24 @@
 #include <QDialog>
 
 class QDialogButtonBox;
-class QGridLayout;
+class QFormLayout;
 class QLineEdit;
 
 class SearchDialog : public QDialog
 {
     Q_OBJECT
     
+    Q_PROPERTY(QString query READ query)
+    
 public:
     explicit SearchDialog(QWidget *parent = 0);
-
-public Q_SLOTS:
-    void accept();
     
-Q_SIGNALS:
-    void search(const QString &query);
+    QString query() const;
 
 private:
     QDialogButtonBox *m_buttonBox;
     
-    QGridLayout *m_layout;
+    QFormLayout *m_layout;
     
     QLineEdit *m_searchEdit;
 };
