@@ -29,7 +29,9 @@ class CuteNews : public QObject
     Q_CLASSINFO("D-Bus Interface", "org.marxoft.cutenews")
     
 public:
-    explicit CuteNews(QDeclarativeEngine *parent);
+    ~CuteNews();
+    
+    static CuteNews* instance();
     
 public Q_SLOTS:
     Q_SCRIPTABLE bool showArticle(int articleId);
@@ -40,10 +42,16 @@ Q_SIGNALS:
     void articleRequested(int articleId);
     
 private:
+    CuteNews();
+    
+    void initEngine();
     QObject* createQmlObject(const QString &fileName);
     
+    static CuteNews *self;
+    
+    QDeclarativeEngine *m_engine;
     QPointer<QObject> m_widget;
-    QPointer<QObject> m_window;
+    QPointer<QObject> m_window;    
 };
     
 #endif // CUTENEWS_H
